@@ -4,7 +4,7 @@
 #                                                                                    #
 #    Author: Clint Cuffy                                                             #
 #    Date:    06/16/2016                                                             #
-#    Revised: 04/08/2017                                                             #
+#    Revised: 02/06/2017                                                             #
 #    UMLS Similarity Word2Phrase Executable Interface Module                         #
 #                                                                                    #
 ######################################################################################
@@ -89,11 +89,10 @@ sub new
     # Try To Locate Word2Vec Executable Files Path
     for my $dir ( @INC )
     {
-        $self->{ _word2PhraseExeDir } = "$dir/External/Word2vec" if ( -e "$dir/External/Word2vec" );                                    # Test Directory
-        $self->{ _word2PhraseExeDir } = "$dir/lib/Word2Vec/External/Word2vec" if ( -e "$dir/lib/Word2Vec/External/Word2vec" );          # Distribution Package Test Directory
-        $self->{ _word2PhraseExeDir } = "$dir/../External/Word2vec" if ( -e "$dir/../External/Word2vec" );                              # Dev Directory
-        $self->{ _word2PhraseExeDir } = "$dir/../../External/Word2vec" if ( -e "$dir/../../External/Word2vec" );                        # Dev Directory
-        $self->{ _word2PhraseExeDir } = "$dir/Word2vec/External/Word2vec" if ( -e "$dir/Word2vec/External/Word2vec" );                  # Release Directory
+        $self->{ _word2PhraseExeDir } = "$dir/External/Word2vec" if ( -e "$dir/External/Word2vec" );                       # Test Directory
+        $self->{ _word2PhraseExeDir } = "$dir/../External/Word2vec" if ( -e "$dir/../External/Word2vec" );                 # Dev Directory
+        $self->{ _word2PhraseExeDir } = "$dir/../../External/Word2vec" if ( -e "$dir/../../External/Word2vec" );           # Dev Directory
+        $self->{ _word2PhraseExeDir } = "$dir/Word2vec/External/Word2vec" if ( -e "$dir/Word2vec/External/Word2vec" );     # Release Directory
     }
 
     # Open File Handler if checked variable is true
@@ -437,12 +436,12 @@ sub WriteLog
     {
         if( ref ( $self ) ne "Word2vec::Word2phrase" )
         {
-            print( GetDate() . " " . GetTime() . " - word2phrase: Cannot Call WriteLog() From Outside Module!\n" );
+            print( GetDate() . " " . GetTime() . " - Word2phrase: Cannot Call WriteLog() From Outside Module!\n" );
             return;
         }
 
         $string = "" if !defined ( $string );
-        print GetDate() . " " . GetTime() . " - word2phrase::$string";
+        print GetDate() . " " . GetTime() . " - Word2phrase::$string";
         print "\n" if( $printNewLine != 0 );
     }
 
@@ -450,7 +449,7 @@ sub WriteLog
     {
         if( ref ( $self ) ne "Word2vec::Word2phrase" )
         {
-            print( GetDate() . " " . GetTime() . " - word2phrase: Cannot Call WriteLog() From Outside Module!\n" );
+            print( GetDate() . " " . GetTime() . " - Word2phrase: Cannot Call WriteLog() From Outside Module!\n" );
             return;
         }
 
@@ -458,7 +457,7 @@ sub WriteLog
 
         if( defined( $fileHandle ) )
         {
-            print( $fileHandle GetDate() . " " . GetTime() . " - word2phrase::$string" );
+            print( $fileHandle GetDate() . " " . GetTime() . " - Word2phrase::$string" );
             print( $fileHandle "\n" ) if( $printNewLine != 0 );
         }
     }
